HiPSCat Import
========================================================================================

Utility for ingesting large survey data into HiPSCat structure.

.. toctree::
   :maxdepth: 1
   :caption: Importing Catalogs

   guide/overview
   guide/command_line
   guide/resume

.. toctree::
   :maxdepth: 1
   :caption: Example Catalogs

   catalogs/overview
   catalogs/allwise
   catalogs/neowise
   catalogs/tic

.. toctree::
   :maxdepth: 1
   :caption: Developers

   guide/contributing
   API Reference <autoapi/index>
